==> mono-1.1.15.tar.gz: mono-1.1.15/mcs/class/corlib/System/ApplicationIdentity.cs <==
//
// System.ApplicationIdentity class
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Runtime.InteropServices;
using System.Runtime.Serialization;

namespace System {

	[Serializable]
	[ComVisible (false)]
	public sealed class ApplicationIdentity: ISerializable {

		private string _fullName;
		private string _codeBase;

		public ApplicationIdentity (string applicationIdentityFullName)
		{
			if (applicationIdentityFullName == null)
				throw new ArgumentNullException ("applicationIdentityFullName");

			if (applicationIdentityFullName.IndexOf (", Culture=") == -1)
				_fullName = applicationIdentityFullName + ", Culture=neutral";
			else
				_fullName = applicationIdentityFullName;
		}

		[MonoTODO ("URL for deployment manifest")]
		public string CodeBase {
			get { return _codeBase; }
		}

		public string FullName {
			get { return _fullName; }
		}

		public override string ToString ()
		{
			return _fullName;
		}

		[MonoTODO]
		void ISerializable.GetObjectData (SerializationInfo info, StreamingContext context)
		{
			if (info == null)
				throw new ArgumentNullException ("info");
		}
	}
}

#endif

==> mono_1.2.2.1.orig.tar.gz: mono-1.2.2.1/mcs/class/corlib/System/ApplicationIdentity.cs <==
//
// System.ApplicationIdentity class
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2004-2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System.Runtime.InteropServices;
using System.Runtime.Serialization;

namespace System {

	[Serializable]
	[ComVisible (false)]
	public sealed class ApplicationIdentity: ISerializable {

		private string _fullName;
		private string _codeBase;

		public ApplicationIdentity (string applicationIdentityFullName)
		{
			if (applicationIdentityFullName == null)
				throw new ArgumentNullException ("applicationIdentityFullName");

			if (applicationIdentityFullName.IndexOf (", Culture=") == -1)
				_fullName = applicationIdentityFullName + ", Culture=neutral";
			else
				_fullName = applicationIdentityFullName;
		}

		//
		// FIXME: "URL for deployment manifest", this message should be clearer!
		// 
		public string CodeBase {
			get { return _codeBase; }
		}

		public string FullName {
			get { return _fullName; }
		}

		public override string ToString ()
		{
			return _fullName;
		}

		[MonoTODO ("Missing serialization")]
		void ISerializable.GetObjectData (SerializationInfo info, StreamingContext context)
		{
			if (info == null)
				throw new ArgumentNullException ("info");
		}
	}
}

#endif
